
0.8.1 / 2015-06-26
==================

  * Check disabled values properly, because of `.isDisabled()` method returning improper value

0.8.0 / 2015-04-03
==================

  * Secondary jack color functionality
  * Enable/disable switch dynamically
  * Destroy event handlers attached to a Switchery instance
  * Meteor.js integration

0.7.0 / 2014-12-09
==================

 * Respect `readonly` attribute on checkbox input
 * Large and small size switches

0.6.3 / 2014-11-02
==================

 * Update component version
 * Added separate Jack color option
 * Add the CSS file to bower.json
 * Fix bug in Hongmi phone
 * Fixing issue found in IE9+ with change event dispatch

0.6.2 / 2014-08-22
==================

 * Prevent text selection on double click

0.6.1 / 2014-07-11
==================

 * Fix switch click state when inside label

0.6.0 / 2014-05-22
==================

  * Corresponding label with `for` attribute of the native input, to change switch state as well
  * Do not copy input's `id` and `name` attributes to switch

0.5.5 / 2014-05-14
==================

  * Set secondary color to be background color on switch off state

0.5.4 / 2014-04-29
==================

  * Fix box-sizing when using Bootstrap 3

0.5.3 / 2014-04-12
==================

  * Detect native checkbox state change

0.5.2 / 2014-04-03
==================

  * Enable event bubbles

0.5.1 / 2014-03-22
==================

  * Fix jack position when switch is hidden

0.5.0 / 2014-02-07
==================

 * Removes the internal validation for loaded switches and lets people do it on their own
 * Sets a data attribute to handle multiple calls for a checkbox

0.4.2 / 2014-01-24
==================

 * Resolve property method issues in IE
 * Disable label checkbox change event
 * Check if element is null

0.4.1 / 2014-01-18
==================

  * Fix Event errors in IE8

0.4.0 / 2014-01-15
==================

 * Use ftlabs/fastclick for mobile browser optimization

0.3.6 / 2014-01-04
==================

  * Generate new standalone file
  * Refactor code
  * Use event constructors to create onchange and click events
  * Updated standalone to dist in bower.json
  * Required files
  * Add development info

0.3.5 / 2013-12-31
==================

  * Proper checkbox value with onchange event

0.3.4 / 2013-12-31
==================

  * Merge ni-c:master
  * Refactor onchange

0.3.3 / 2013-12-28
==================

  * Merge pull request from tenbits:patch-1
  * Leave first line empty
  * Undefined option's property
  * Update Readme
  * Update standalone
  * Changelog
  * Standalone -> dist, update Readme, add changelog

0.3.2 / 2013-12-27
==================

  * Standalone -> dist, update Readme, add changelog
  * Merge pull request from vesln:min
  * Add minified versions
  * Minify CSS & JS
  * Fix the standalone build & improve Makefile
  * Ignore node_modules
  * Add package.json
  * Disabled opacity option
  * Disabled opacity option
  * Insert switch after target element
  * Require Transitionize
